PinInputController class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
text
↔ String
-
getter/setter pair
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
attach({required void onEffect(PinInputEffectRequest effect), required VoidCallback onClose})
→ void
-
내부 위젯이 컨트롤러에 자신을 연결할 때 사용합니다.
-
clear()
→ void
-
-
close()
→ void
-
사용자가 원하는 타이밍에 시트를 닫습니다.
-
detach()
→ void
-
내부 위젯이 dispose 시 컨트롤러 연결을 해제할 때 사용합니다.
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
error({bool clearOnError = true, Duration revertAfter = const Duration(milliseconds: 800), String? message})
→ void
-
실패(에러) 효과를 적용합니다.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setCode(String nextCode)
→ void
-
내부 위젯에서 입력 완료 코드를 주입할 때 사용합니다.
-
success()
→ void
-
성공 효과를 적용합니다.
-
toString()
→ String
-
A string representation of this object.
inherited